Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | class |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
privacyforms_pdf / __init__.py | (no class) |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / cli.py | (no class) |  | 100% | 121 | 0 | 2 |  | 100% | 20 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFCPUError |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFCPUNotFoundError |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFCPUExecutionError |  | 100% | 3 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormNotFoundError |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FormValidationError |  | 100% | 6 | 0 | 0 |  | 100% | 2 | 0 |  | 100%
privacyforms_pdf / extractor.py | FieldNotFoundError |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | FormField |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormData |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
privacyforms_pdf / extractor.py | PDFFormExtractor |  | 100% | 153 | 0 | 0 |  | 96% | 72 | 3 |  | 99%
privacyforms_pdf / extractor.py | (no class) |  | 100% | 61 | 0 | 2 |  | 100% | 0 | 0 |  | 100%
Total |  |  | 100% | 347 | 0 | 4 |  | 97% | 94 | 3 |  | 99%

No items found using the specified filter.